@@ -145,7 +145,7 @@ type Gauge struct {
 type Task struct {
 	ID         string `xml:"id"`
 	Name       string `xml:"name"`
-	Quantum    uint64 `xml:"quantum"`
+	Quantum    int64  `xml:"quantum"`
 	References uint64 `xml:"references"`
 	State      string `xml:"state"`
 }
